==> hs-language-c-0.3.1.1_2.tbz: lib/language-c-0.3.1.1/register.sh <==
#!/bin/sh

echo 'name: language-c
version: 0.3.1.1
license: BSD3
copyright: LICENSE
maintainer: benedikt.huber@gmail.com
stability: experimental
homepage: http://www.sivity.net/projects/language.c/
package-url:
description: Language C is a haskell library for the analysis and generation of C code.
             It features a complete, well tested parser and pretty printer for all of C99 and a large
             set of GNU extensions.
category: Language
author: AUTHORS
exposed: True
exposed-modules: Language.C Language.C.Data
                 Language.C.Data.Position Language.C.Data.Ident
                 Language.C.Data.Error Language.C.Data.Name Language.C.Data.Node
                 Language.C.Data.InputStream Language.C.Syntax Language.C.Syntax.AST
                 Language.C.Syntax.Constants Language.C.Syntax.Ops Language.C.Parser
                 Language.C.Pretty Language.C.System.Preprocess
                 Language.C.System.GCC Language.C.Analysis
                 Language.C.Analysis.SemError Language.C.Analysis.SemRep
                 Language.C.Analysis.DefTable Language.C.Analysis.TravMonad
                 Language.C.Analysis.AstAnalysis Language.C.Analysis.DeclAnalysis
                 Language.C.Analysis.Debug Language.C.Analysis.Export
hidden-modules: Language.C.Analysis.NameSpaceMap
                Language.C.Data.RList Language.C.Parser.Builtin
                Language.C.Parser.Lexer Language.C.Parser.ParserMonad
                Language.C.Parser.Tokens Language.C.Parser.Parser
import-dirs: /usr/local/lib/language-c-0.3.1.1/ghc-6.10.4
library-dirs: /usr/local/lib/language-c-0.3.1.1/ghc-6.10.4
              /usr/local/lib
hs-libraries: HSlanguage-c-0.3.1.1
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: array-0.2.0.0 base-3.0.3.1 bytestring-0.9.1.4
         containers-0.2.0.1 directory-1.0.0.3 filepath-1.1.0.2
         pretty-1.0.1.0 process-1.0.1.1
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/language-c-0.3.1.1/html/language-c.haddock
haddock-html: /usr/local/share/doc/language-c-0.3.1.1/html' | /usr/local/bin/ghc-pkg update -

==> hs-language-c-0.3.2.tbz: lib/language-c-0.3.2/register.sh <==
#!/bin/sh

echo 'name: language-c
version: 0.3.2
license: BSD3
copyright: LICENSE
maintainer: benedikt.huber@gmail.com
stability: experimental
homepage: http://www.sivity.net/projects/language.c/
package-url:
description: Language C is a haskell library for the analysis and generation of C code.
             It features a complete, well tested parser and pretty printer for all of C99 and a large
             set of GNU extensions.
category: Language
author: AUTHORS
exposed: True
exposed-modules: Language.C Language.C.Data
                 Language.C.Data.Position Language.C.Data.Ident
                 Language.C.Data.Error Language.C.Data.Name Language.C.Data.Node
                 Language.C.Data.InputStream Language.C.Syntax Language.C.Syntax.AST
                 Language.C.Syntax.Constants Language.C.Syntax.Ops Language.C.Parser
                 Language.C.Pretty Language.C.System.Preprocess
                 Language.C.System.GCC Language.C.Analysis
                 Language.C.Analysis.SemError Language.C.Analysis.SemRep
                 Language.C.Analysis.DefTable Language.C.Analysis.TravMonad
                 Language.C.Analysis.AstAnalysis Language.C.Analysis.DeclAnalysis
                 Language.C.Analysis.Debug Language.C.Analysis.Export
hidden-modules: Language.C.Analysis.NameSpaceMap
                Language.C.Data.RList Language.C.Parser.Builtin
                Language.C.Parser.Lexer Language.C.Parser.ParserMonad
                Language.C.Parser.Tokens Language.C.Parser.Parser
import-dirs: /usr/local/lib/language-c-0.3.2/ghc-6.10.4
library-dirs: /usr/local/lib/language-c-0.3.2/ghc-6.10.4
              /usr/local/lib
hs-libraries: HSlanguage-c-0.3.2
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: array-0.2.0.0 base-4.1.0.0 bytestring-0.9.1.4
         containers-0.2.0.1 directory-1.0.0.3 filepath-1.1.0.2
         pretty-1.0.1.0 process-1.0.1.1 syb-0.1.0.1
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/language-c-0.3.2/html/language-c.haddock
haddock-html: /usr/local/share/doc/language-c-0.3.2/html' | /usr/local/bin/ghc-pkg update -
